@@ -1,7 +1,5 @@
-function a() {
-}
-function b() {
-}
+function a() {}
+function b() {}
 function foo({ a: b__2  }) {
     expect(b__2).toBe('a');
 }
